# Postgrey

[![Version](https://badge.fury.io/py/postgrey.svg)](https://pypi.python.org/pypi/postgrey)
[![Downloads](https://img.shields.io/pypi/dm/postgrey.svg)](https://pypi.python.org/pypi/postgrey)
![Stars](https://img.shields.io/github/stars/5elenay/postgrey)
![Commits](https://img.shields.io/github/commit-activity/w/5elenay/postgrey)

🐘 Simple, Fast, Async & ORM PostgreSQL database client based on [Asyncpg](https://github.com/MagicStack/asyncpg) for Python.

## Features

- **Simple**: You can learn Postgrey in less than a hours!
- **Fast**: Since Postgrey is based on Asyncpg, Postgrey is really fast.
- **Secure**: Postgrey has SQL injection protection.
- **ORM**: You don't need to learn SQL for your apps.
- **Freedom**: If you are a SQL master, you still can execute SQL commands.
- **Asyncpg**: You easily can use Asyncpg in Postgrey.

## Documentation

Check [/docs/](https://github.com/5elenay/postgrey/tree/main/docs) folder for documentation.

## About
- **Version**: 0.0.1
- **Requires**: `Python 3.6 >=`
- **Links**: [PyPi](https://pypi.org/project/postgrey) | [GitHub](https://github.com/5elenay/postgrey)